@@ -55,10 +55,10 @@ from ..context import AnyContext
 from ..prompt import Prompt
 from ..response import Response, ResponseSet
 from ..task import Task
-from ..utils import LOG, HashableConfig, dedent
+from ..utils import LOG, Configurable, dedent
 
 
-class GoogleKwdConfig(HashableConfig):
+class GoogleKwdConfig(Configurable):
     """Configuration for Google Ads API access."""
 
     keywords: tuple[str, ...] | None = None
@@ -79,7 +79,10 @@ class GoogleKwdConfig(HashableConfig):
     max_ideas: int = Field(100, le=10_000)
     """Maximum number of additional keyword ideas to fetch (if `ideas` is True)."""
     language: str = "en"
-    """The language to use for keyword data (e.g., 'en' for English)."""
+    """The resource name of the language to target. Each keyword belongs to some set of languages;
+    a keyword is included if language is one of its languages. If not set, all keywords will be
+    included. (e.g., 'en' for English).
+    """
     country: str = "us"
     """The geographical target for keyword data (e.g., 'us' for United States)."""
     metrics_start: str | None = None
@@ -210,10 +213,15 @@ def connect_ads_client(config: str | Path | dict | None = None) -> GoogleAdsClie
                 json.dump(json_key, fp)
                 fp.flush()
                 config["json_key_file_path"] = fp.name
+                safe_config = {
+                    k: v for k, v in config.items() if k not in ("json_key", "developer_token")
+                }
+                LOG.info(f"Connecting to Google Ads API with credentials dict:\n{safe_config}")
                 client = GoogleAdsClient.load_from_dict(config)
 
             return client  # noqa: RET504
 
+        LOG.info(f"Connecting to Google Ads API with credentials dict:\n{config}")
         return GoogleAdsClient.load_from_dict(config)
 
     if isinstance(config, str | Path):
@@ -398,9 +406,10 @@ def add_trend_columns(df: DataFrame) -> DataFrame:
     return df
 
 
-def process_keywords(
+def process_keywords(  # noqa: PLR0912
     response: GenerateKeywordIdeasPager | GenerateKeywordHistoricalMetricsResponse,
     collect_volumes: bool = True,
+    zeros_to_nans: bool = True,
 ) -> DataFrame:
     """Process Google Ads API keyword response into a DataFrame."""
 
@@ -461,6 +470,19 @@ def process_keywords(
         df = collect_volume_columns(df)
         df = add_trend_columns(df)
 
+    # Convert micros to dollars/euros, and 0s to NaNs
+    for col in (
+        "average_cpc_micros",
+        "low_top_of_page_bid_micros",
+        "high_top_of_page_bid_micros",
+    ):
+        if col in df.columns:
+            name = col.replace("_micros", "")
+            df[name] = df[col] / 1_000_000
+            if zeros_to_nans:
+                df[name] = df[name].replace(0, np.nan)
+            df = df.drop(columns=col)
+
     return df
 
 
